## Pulse Oximetry
Pulse oximetry devices use several LEDs to measure pulse rate and blood oxygen content. The LEDs are tuned to specific wavelengths corresponding to the absorbance bands of oxygenated and reduced hemoglobin; by cycling through the LEDs rapidly the device compensates for skin differences and ambient light, returning saturation and pulse rate.

### Background
- overview of pulse oximetry physics and engineering challenges from 1989: Tremper, Kevin K., and Steven J. Barker. "Pulse oximetry." Anesthesiology: The Journal of the American Society of Anesthesiologists 70.1 (1989): 98-108.
    - engineering challenges identified
        - LED center wavelength consistency
        - the other two hemoglobins (MetHb and COHb)
        - signal artifacts: physical movement, signal:noise ratio, ambient light
        - calibration curve accuracy
- lots of IP from Masimo Corp
    - https://patents.google.com/patent/US7280858B2/en (active thru 2025)
    - https://patents.google.com/patent/US6697656B1/en (exp 6/2020)
    - https://patents.google.com/patent/US6684090B2/en (exp)
- earlier overview: Yelderman, Mark, and William New. "Evaluation of pulse oximetry." Anesthesiology: The Journal of the American Society of Anesthesiologists 59.4 (1983): 349-351.
- changing LED wavelengths with temp: ~0.1 nm/C: Reynolds, K. J., et al. "Temperature dependence of LED and its theoretical effect on pulse oximetry." British journal of anaesthesia 67.5 (1991): 638-643.
    - "... equation (2) is only an approximation and pulse oximeters are usually calibrated empirically using data obtained by inducing hypoxia in healthy volunteers."

### Commercial Example
A quick teardown of a ~$20 500BL from Walgreens revealed no [integrated photonics package](https://www.maximintegrated.com/en/products/interface/sensor-interface/MAX30101.html) or [signal processing ASIC](https://www.maximintegrated.com/en/products/interface/sensor-interface/MAX32664.html); instead, the device uses a bi-color IR/red LED on one side of a spring-loaded plastic clam-shell and a PCB with a decent sized photodiode on the other, paired with an [SGM8634](www.sg-micro.com/uploads/soft/20190626/1561538475.pdf) op-amp and an [STM32F100](https://www.st.com/en/microcontrollers-microprocessors/stm32f100-value-line.html)-series 32-bit Arm Cortex M3 microcontroller. The display is a custom multi-segment LED device, but the PCB labels suggest an OLED is used for an alternate model. TX/RX test points were spotted that could be investigated further; with any luck, these could be used to pull live data out of the instrument.

![pulseox1](img/pulseox_1.jpg)

![pulseox2](img/pulseox_2.jpg)

![pulseox3](img/pulseox_3.jpg)

### Operational Theory
Pulse oximetry is based on the [Beer-Lambert law](https://en.wikipedia.org/wiki/Beer%E2%80%93Lambert_law), a principle that relates the concentration of a species to the attenuation of light through a sample:
```math
I=I_{in}e^{-(DC\epsilon)}
```
where $`I`$ is the intensity of light transmitted through the sample; $`I_{in}`$ is the intensity of the light prior to absorption by the sample; $`D`$ is the optical path length; $`C`$ is the solute concentration; and $`\epsilon`$ is the extinction coefficient, the sample's absorption at a given wavelength of light. Typical commercial pulse oximeters use a red LED (660 nm) and an IR LED (940 nm) to quantify the relative concentration of reduced and oxygen-rich hemoglobin in a person's bloodstream based on the following absorbance curves:

![hemoglobin_curve](img/hemoglobin_curve.png)

_Figure source: Bülbül, Ali & Küçük, Serdar. (2016). Pulse Oximeter Manufacturing & Wireless Telemetry for Ventilation Oxygen Support. International Journal of Applied Mathematics, Electronics and Computers. 211-211. 10.18100/ijamec.270309._

In order to differentiate the slight intensity change caused by varying blood oxygen concentration from errors related to skin absorbance and venous blood (whose oxygen has already been taken up by cells), the signal processing algorithm isolates the AC portion of the signal, since within a reasonable range (~0.5 - 3 Hz) this corresponds to blood rushing through arteries with each heartbeat. This _pulsatile arterial blood_ increases the optical path length of the measurement as blood pressure swells the arteries, producing periodic oscillations in the absorption signal. The other contributors to absorption, such as tissue and venous/capillary blood, are effectively constant in this frequency regime. By calculating the ratio of the AC and DC signals at each wavelength, then taking the ratio of these two absorption ratios, a value $`R`$ can be determined which is only related to the relative concentration of oxyhemoglobin (O2Hb) and reduced hemoglobin (Hb):

```math
R=\frac{A_{AC_{660}}/A_{DC_{660}}}{A_{AC_{940}}/A_{DC_{940}}}
```

As the photodiode sensor does not differentiate by wavelength, the device rapidly cycles between red, IR, and no LED, allowing the system to compensate for ambient light as well. The cycling speed must be substantially faster than the heart rate, since the ratio $`R`$ assumes absorption at all wavelengths is carried out simultaneously in order to cancel out path length.

Note that methemoglobin (MetHb) and carboxyhemoglobin (CoHb) are not factored in with this method and will thus cause systematic errors; the above calculation assumes these two compounds are minimally present. Additional wavelengths are needed to quantify all four hemoglobin species.
